@@ -6,11 +6,13 @@ from FreeTAKServer.model.FTSModel.Event import Event as event
 import json as jsonmodule
 from FreeTAKServer.controllers.XMLCoTController import XMLCoTController
 from FreeTAKServer.controllers.DatabaseControllers.DatabaseController import DatabaseController
-from FreeTAKServer.model.RestMessages.EmergencyPost import EmergencyPost
+from FreeTAKServer.model.RestMessages.EmergencyPost import EmergencyPost, RestEnumerations
 from FreeTAKServer.model.RestMessages.EmergencyDelete import EmergencyDelete
 loggingConstants = LoggingConstants()
 logger = CreateLoggerController("SendGeoChatController").getLogger()
 
+from geopy import Nominatim
+
 class SendEmergencyController:
     def __init__(self, json):
         if isinstance(json, EmergencyPost):
@@ -28,19 +30,26 @@ class SendEmergencyController:
     def _serializeJsonToModel(self, object, json):
         # runs if emergency is on
         if isinstance(json, EmergencyPost):
-            object.settype(json.getemergencyType())
+            object.settype(RestEnumerations.emergencyTypes[json.getemergencyType()])
             object.detail.contact.setcallsign(json.getname())
             object.detail.emergency.settype(json.getemergencyType())
-            object.point.setlat(json.getlatitude())
-            object.point.setlon(json.getlongitude())
+            if json.getaddress():
+                locator = Nominatim(user_agent="myGeocoder")
+                location = locator.geocode(json.getaddress())
+                object.point.setlon(location.longitude)
+                object.point.setlat(location.latitude)
+            else:
+                object.point.setlon(json.getlongitude())
+                object.point.setlat(json.getlatitude())
             DatabaseController().create_ActiveEmergency(object)
             return object
 
         # runs if emergency is off
         elif isinstance(json, EmergencyDelete):
             object.setuid(json.getuid())
-            DatabaseController().remove_ActiveEmergency(query=f'uid == "{object.uid}"')
-            object.settype('b-a-o-ctl')
+            DatabaseController().remove_ActiveEmergency(query=f'uid = "{object.uid}"')
+            object.settype('b-a-o-can')
+            object.detail.emergency.setcancel('true')
             return object
 
     def setCoTObject(self, CoTObject):
